export const THEME_KEY = 'DONT_TRY_THIS__THEME_KEY';
export function handler() {
    const current = localStorage.getItem(THEME_KEY);
    const toSet = current === 'light' ? 'dark' : 'light';
    localStorage.setItem(THEME_KEY, toSet);
    if (current) {
        document.documentElement.classList.remove(current);
    }
    document.documentElement.classList.add(toSet);
}
export function initTheme() {
    const theme = localStorage.getItem(THEME_KEY);
    if (theme === 'dark') {
        document.documentElement.classList.add('dark');
    }
    else if ((!theme && window.matchMedia('(prefers-color-scheme: dark)').matches)) {
        document.documentElement.classList.add('dark');
        localStorage.setItem(THEME_KEY, 'dark');
    }
    else if (!theme) {
        localStorage.setItem(THEME_KEY, 'light');
    }
}
export const internal = `
function init() {
  const theme = localStorage.getItem('${THEME_KEY}');

  if (theme === 'dark') {
    document.documentElement.classList.add('dark');
  } else if ((!theme && window.matchMedia('(prefers-color-scheme: dark)').matches)) {
    document.documentElement.classList.add('dark');
    localStorage.setItem('${THEME_KEY}', 'dark');
  } else if (!theme) {
    localStorage.setItem('${THEME_KEY}', 'light');
  }
}

init()
`;
/**
 * String representation of init script. Used within application.theme-init-script.svelte to
 * dynamically load a header script to set theme. A header script ensures no theme 'flicker'
 * is shown when first loading the script.
 *
 * Since we are not able to import values into header scripts, a string representation is used
 * in conjunction with {#html script} to inject values such as the theme key.
*/
export const init = `<script>${internal}<\/script>`;
